@@ -7,6 +7,7 @@ import (
 	"encoding/json"
 	"errors"
 	"fmt"
+	"go/build"
 	"io"
 	"io/fs"
 	"net/http"
@@ -448,6 +449,12 @@ func newConfig(options ...configOption) (*Config, error) {
 	} {
 		c.addTemplateFunc(key, value)
 	}
+	for _, releaseTag := range build.Default.ReleaseTags {
+		if releaseTag == "go1.17" {
+			c.addTemplateFunc("exit", c.exitTemplateFunc)
+			break
+		}
+	}
 
 	for _, option := range options {
 		if err := option(c); err != nil {
@@ -594,7 +601,7 @@ func (c *Config) applyArgs(
 		}
 	}
 	if keptGoingAfterErr {
-		return ExitCodeError(1)
+		return chezmoi.ExitCodeError(1)
 	}
 
 	return nil
@@ -814,7 +821,7 @@ func (c *Config) defaultPreApplyFunc(
 		case choice == "skip":
 			return chezmoi.Skip
 		case choice == "quit":
-			return ExitCodeError(1)
+			return chezmoi.ExitCodeError(1)
 		default:
 			return nil
 		}
