@@ -5,7 +5,6 @@ import (
 	"fmt"
 	"io/fs"
 	"os/exec"
-	"path"
 	"path/filepath"
 	"runtime"
 
@@ -19,6 +18,11 @@ type ioregData struct {
 	value map[string]interface{}
 }
 
+func (c *Config) exitTemplateFunc(code int) string {
+	returnTemplateError(chezmoi.ExitCodeError(code))
+	return ""
+}
+
 func (c *Config) fromYamlTemplateFunc(s string) interface{} {
 	var data interface{}
 	if err := chezmoi.FormatYAML.Unmarshal([]byte(s), &data); err != nil {
@@ -30,7 +34,7 @@ func (c *Config) fromYamlTemplateFunc(s string) interface{} {
 
 func (c *Config) includeTemplateFunc(filename string) string {
 	var absPath chezmoi.AbsPath
-	if path.IsAbs(filename) {
+	if filepath.IsAbs(filename) {
 		var err error
 		absPath, err = chezmoi.NewAbsPathFromExtPath(filename, c.homeDirAbsPath)
 		if err != nil {
